@@ -495,6 +495,8 @@ class ParametersLEDET:
             self.variableGroupVariables = asdict(self.Variables)
             for k in variableGroup:
                 if (k == "BlankRows"): continue
+                if k =='overwrite_f_internalVoids_inGroup': continue
+                if k == 'overwrite_f_externalVoids_inGroup': continue
                 print(variableLabels[k])
                 print(k, variableGroup[k])
 
