@@ -498,7 +498,7 @@ class ParametersCOSIM:
         ## Do some kind of check
         TurnNumber_All = TurnNumber*N_PAR
 
-        print(TurnNumber_All,'will be simulated in parallel.')
+        print(TurnNumber_All,' Turns will be simulated in parallel.')
         if TurnNumber_All >= 10000:
             print("You are trying to simulate ",str(TurnNumber_All),"in parallel mode. \n")
             maxN_PAR = np.floor(10000/TurnNumber)
